@@ -6,7 +6,8 @@
 
 api.log("loading api-core...");
 
-var MAX_NEARBY_DISTANCE = 100000; //100km
+api.MAX_NEARBY_DISTANCE = 100000; //100km
+api.MAX_FEED_SIZE = 100;
 
 var API_VERSION = "20120910";
 
